================================================
Django-Oscar - Flexible e-commerce on Django 1.3
================================================

*django-oscar* is an e-commerce framework for Django 1.3 designed for building domain-driven
e-commerce sites.  It is structured such that any part of the core
functionality can be customised to suit the needs of your project.  This allows it to handle
a wide range of e-commerce sites, from large-scale B2C sites to complex B2B sites rich in
domain-specific business logic.

`Read the docs`_

.. _`Read the docs`: http://django-oscar.readthedocs.org/en/latest/

Credits
-------
* Created by David Winterbottom (`@codeinthehole`_) in the small pockets of time when his
  new-born son was sleeping.
* Important early contributions made by Andrew Ingram (`@AndrewIngram`_) and through collaboration
  with `Mirumee`_
* Developed and maintained by `Tangent Labs`_, a London-based digital agency

.. _`@codeinthehole`: https://twitter.com/codeinthehole
.. _`@AndrewIngram`: https://twitter.com/AndrewIngram
.. _`Mirumee`: http://mirumee.com
.. _`Tangent Labs`: http://www.tangentlabs.co.uk

Changelog
---------
0.1-beta
~~~~~~~~
* Initial release - is working fine for the two main Tangent projects of summer 2011
* Docs are a bit stale and need updating